#include "scenegraph.h"
#include "myglwidget.h"

SceneGraph::SceneGraph()
{
    nodes = QList<RigidBodyTransformation*>();
    views = QList<MyGLWidget*>();
    idCounter = 0;
    boxIndex = 1;
    nextBoxName = "Box 1";
}

void SceneGraph::registerView(MyGLWidget* view){
    views.append(view);
}

RigidBodyTransformation* SceneGraph::addBox(int tesselation){

   Box* b = new Box(idCounter,nextBoxName,tesselation);
   idCounter++;
   boxIndex++;
   nextBoxName = "Box " + boxIndex;

   qDebug("New box added in scenegraph");

   RigidBodyTransformation* r = new RigidBodyTransformation(b);
   nodes.append(r);

   qDebug("Notify Views...");
   notifyViews();

   return r;
}

void SceneGraph::drawAll(){

    QList<RigidBodyTransformation*>::iterator i;
    for (i = nodes.begin(); i != nodes.end(); ++i){
        (*i)->drawChild();
    }
}

void SceneGraph::addRotation(RigidBodyTransformation *r, QQuaternion diff){
    r->addRotation(diff);
    notifyViews();
}

void SceneGraph::addTranslation(RigidBodyTransformation *r, QVector3D diff){
    r->addTranslation(diff);
    notifyViews();
}

void SceneGraph::notifyViews(){
    QList<MyGLWidget*>::iterator i;
    for (i = views.begin(); i != views.end(); i++){
        (*i)->modelChanged();
    }
}
